@@ -66,11 +66,9 @@ class IncallWebService(AbstractWebService):
     ]
 
     def search_by_number(self, number):
-        number = str(number)
+        number = unicode(number)
         incalls = self.search(number)
         return [incall for incall in incalls if incall.number == number]
 
 
 register_ws_class(IncallWebService, 'incalls')
-# deprecated name
-register_ws_class(IncallWebService, 'incall')
