@@ -159,5 +159,3 @@ class QueueWebService(AbstractWebService):
 
 
 register_ws_class(QueueWebService, 'queues')
-# deprecated name
-register_ws_class(QueueWebService, 'queue')
